<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Plugin aktivieren',
	'affichage' => 'Anzeigen',
	'aide_non_disponible' => 'Dieser Teil der Online-Hilfe ist in dieser Sprache noch nicht verfügbar.',
	'annuler_recherche' => 'Sucheingabe löschen',
	'auteur' => 'Autor:',
	'avis_acces_interdit' => 'Zugang verweigert.',
	'avis_article_modifie' => 'Achtung, @nom_auteur_modif@ hat vor @date_diff@ Minute(n) an diesem Artikel gearbeitet.',
	'avis_aucun_resultat' => 'Kein Ergebnis.',
	'avis_base_inaccessible' => 'Keine Verbindung mit Datenbank @base@ möglich.',
	'avis_chemin_invalide_1' => 'Der gewählte Pfad',
	'avis_chemin_invalide_2' => 'scheint nicht zu stimmen. Bitte kehren Sie zur vorigen Seite zurück und überprüfen sie die Angaben.',
	'avis_connexion_echec_1' => 'Die Verbindung zur Datenbank ist fehlgeschlagen.',
	'avis_connexion_echec_2' => 'Kehren Sie zur vorigen Seite zurück und überprüfen sie ihre Eingaben.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Bei vielen Servern müssen Sie Ihre Datenbank ausdrücklich <b>freischalten lassen</b> um sie nutzen zu können. Falls die Verbindung wieder fehlschlägt, stellen Sie bitte sicher, dass Ihre Datenbank freigeschaltet wurde.',
	'avis_connexion_erreur_creer_base' => 'Die Datenbank konnte nicht erstellt werden.',
	'avis_connexion_erreur_nom_base' => 'Der Datenbankname darf nur Buchstaben, Ziffern und Bindestriche "-" enthalten.',
	'avis_connexion_ldap_echec_1' => 'Die Verbindung zum LDAP-Server ist fehlgeschlagen.',
	'avis_connexion_ldap_echec_2' => 'Kehren Sie zur vorigen Seite zurück und überprüfen sie ihre Eingaben.',
	'avis_connexion_ldap_echec_3' => 'Sie können Benutzer auch ohne LDAP-Support importieren.',
	'avis_deplacement_rubrique' => 'Achtung! diese Rubrik enthält @contient_breves@ Meldungen@scb@: wenn Sie Rubrik verschieben wollen, markieren Sie bitte zur Bestätigung dieses Kästchen.',
	'avis_erreur_connexion_mysql' => 'Verbindungsfehler (SQL)',
	'avis_espace_interdit' => '<b>Gesperrter Bereich</b><div>SPIP ist bereits installiert.</div>',
	'avis_lecture_noms_bases_1' => 'Das Installationsprogramm konnte die Namen der vorhandenen Datenbanken nicht lesen.',
	'avis_lecture_noms_bases_2' => 'Entweder ist keine Datenbank vorhanden oder die Funktion zum Auflisten der Datenbanken ist aus Sciherheitsgründen abgeschaltet
(Das ist bei vielen Webhostern der Fall).',
	'avis_lecture_noms_bases_3' => 'Im zweiten Fall ist wahrscheinlich eine Datenbank vorhanden, die Ihren Anmeldenamen trägt:',
	'avis_non_acces_page' => 'Sie haben keinen Zugriff auf diese Seite.',
	'avis_operation_echec' => 'Aktion fehlgeschlagen.',
	'avis_operation_impossible' => 'Aktion nicht möglich',
	'avis_suppression_base' => 'ACHTUNG, Daten werden unwiderruflich gelöscht.',

	// B
	'bouton_acces_ldap' => 'LDAP Zugang hinzufügen',
	'bouton_ajouter' => 'Hinzufügen',
	'bouton_annuler' => 'Abbrechen',
	'bouton_cache_activer' => 'Cache aktivieren',
	'bouton_cache_desactiver' => 'Cache vorübergehend abschalten',
	'bouton_demande_publication' => 'Artikel zur Veröffentlichung vorschlagen',
	'bouton_desactive_tout' => 'Alles deaktivieren',
	'bouton_desinstaller' => 'Deinstallieren',
	'bouton_effacer_tout' => 'ALLES löschen',
	'bouton_envoyer_message' => 'Nachricht fertig: Senden',
	'bouton_fermer' => 'Schließen',
	'bouton_mettre_a_jour_base' => 'Datenbank updaten',
	'bouton_modifier' => 'Ändern',
	'bouton_radio_afficher' => 'Anzeigen',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Auf der Liste angemeldeter Redakteure anzeigen',
	'bouton_radio_envoi_annonces_adresse' => 'Editorische Ankündigungen an diese Adresse senden:',
	'bouton_radio_envoi_liste_nouveautes' => 'Liste der neuesten Veröffentlichungen verschicken',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ich will nicht auf dieser Liste zu sehen sein.',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Keine editorischen Ankündigungen verschicken',
	'bouton_redirection' => 'UMLEITUNG',
	'bouton_relancer_installation' => 'Installation wiederholen',
	'bouton_suivant' => 'weiter',
	'bouton_tenter_recuperation' => 'Reparatur versuchen',
	'bouton_test_proxy' => 'Proxy testen',
	'bouton_vider_cache' => 'Cache leeren',

	// C
	'cache_modifiable_webmestre' => 'Dieser Parameter kann vom Webmaster eingestellt werden.',
	'calendrier_synchro' => 'Wenn Sie eine mit <b>iCal</b> kompatibles PIM-Programm verwenden, könne Sie es mit den Einträgen dieser Website synchronisieren.',
	'config_activer_champs' => 'Aktivieren Sie folgende Felder',
	'config_choix_base_sup' => 'Eine Datenbank auf diesem Server angeben',
	'config_erreur_base_sup' => 'SPIP kann nicht auf die Liste der verfügbaren Datenbanken zugreifen.',
	'config_info_base_sup' => 'Wenn Sie andere Datenbanken auf dem selben Server oder auf einem anderen mit SPIP abfragen möchten, können Sie sie mit dem Formular weiter unten deklarieren. Wenn Sie Felder leer lassen, werden die Verbindungsdaten der Hauptdatenbank verwendet.',
	'config_info_base_sup_disponibles' => 'Bereits abfragbare Datenbanken:',
	'config_info_enregistree' => 'Neue Einstellungen wurden gespeichert',
	'config_info_logos' => 'Jedes Element der Website kann ein Logo und ein «mouseover-Logo» erhalten.',
	'config_info_logos_utiliser' => 'Logos verwenden',
	'config_info_logos_utiliser_non' => 'Logos nicht verwenden',
	'config_info_logos_utiliser_survol' => 'Mouseover-Logos verwenden',
	'config_info_logos_utiliser_survol_non' => 'Mouseover-Logos nicht verwenden',
	'config_info_redirection' => 'Mit dieser Option können Sie virtuelle Artikel anlegen, die als Weiterleitung zu Artikeln anderer Websites oder ausserhalb von SPIP funktionieren.',
	'config_redirection' => 'Virtuelle Artikel',
	'config_titre_base_sup' => 'Deklaration einer zusätzlichen Datenbank',
	'config_titre_base_sup_choix' => 'Wählen Sie eine zusätzliche Datenbank',
	'connexion_ldap' => 'Verbindung:',
	'creer_et_associer_un_auteur' => 'Autor anlegen und zuordnen',

	// D
	'date_mot_heures' => 'Stunden',

	// E
	'ecran_securite' => ' + Sicherheitsschirm @version@',
	'email' => 'E-Mail',
	'email_2' => 'E-Mail:',
	'en_savoir_plus' => 'Weitere Informationen',
	'entree_adresse_annuaire' => 'Adresse des Verzeichnisses',
	'entree_adresse_email' => 'Ihre E-Mail Adresse',
	'entree_adresse_email_2' => 'Mailadresse',
	'entree_base_donnee_1' => 'Adresse des Datenbankservers',
	'entree_base_donnee_2' => '(Oftmals entspricht diese Adresse der Ihrer Website, sie kann auch einfach „localhost“ lauten und gelegentlich darf das Feld leer bleiben.)',
	'entree_biographie' => 'Ganz kurze Vorstellung / Lebenslauf',
	'entree_chemin_acces' => 'Bitte den <b>Pfad angeben</b>:',
	'entree_cle_pgp' => 'Ihr öffentlicher PGP-Schlüssel',
	'entree_cle_pgp_2' => 'PGP-Schlüssel',
	'entree_contenu_rubrique' => '(Inhalt der Rubrik)',
	'entree_identifiants_connexion' => 'Ihre Verbindungsdaten ...',
	'entree_identifiants_connexion_2' => 'Logindaten',
	'entree_informations_connexion_ldap' => 'Bitte tragen Sie in dieses Formular die Zugangsdaten zu Ihrem LDAP-Verzeichnis ein. Sie erhalten diese Informationen von Ihrem System- oder Netzwerkadministrator.',
	'entree_infos_perso' => 'Wer sind Sie?',
	'entree_infos_perso_2' => 'Wer ist der Autor?',
	'entree_interieur_rubrique' => 'In der Rubrik:',
	'entree_liens_sites' => '<b>Hyperlink</b> (Quelle, Website zum Thema ...)',
	'entree_login' => 'Ihr Login',
	'entree_login_connexion_1' => 'Login für die Verbindung',
	'entree_login_connexion_2' => '(Dieser entspricht häufig Ihrem FTP-Login, bleibt in manchen Fällen leer)',
	'entree_mot_passe' => 'Ihr Passwort',
	'entree_mot_passe_1' => 'Passwort für die Verbindung',
	'entree_mot_passe_2' => '(Entspricht häufig Ihrem FTP-Login, bleibt in manchen Fällen leer)',
	'entree_nom_fichier' => 'Bitte geben Sie den Namen der Datei @texte_compresse@ an:',
	'entree_nom_pseudo' => 'Ihr Name oder Pseudonym',
	'entree_nom_pseudo_1' => '(Ihr Name oder Nickname)',
	'entree_nom_pseudo_2' => 'Name oder Pseudonym',
	'entree_nom_site' => 'Der Titel Ihrer Website',
	'entree_nom_site_2' => 'Name der Website des Autors',
	'entree_nouveau_passe' => 'Neues Passwort',
	'entree_passe_ldap' => 'Passwort',
	'entree_port_annuaire' => 'Port (Nummer) des Verzeichnisses',
	'entree_signature' => 'Unterschrift',
	'entree_titre_obligatoire' => '<b>Titel</b> [Pflichtfeld]<br />',
	'entree_url' => 'Adresse (URL) Ihrer Website',
	'entree_url_2' => 'Adresse (URL) der Website',
	'erreur_connect_deja_existant' => 'Ein Server mit diesem Namen existiert bereits.',
	'erreur_email_deja_existant' => 'Diese Adresse ist bereits gespeichert.',
	'erreur_nom_connect_incorrect' => 'Dieser Servername ist nicht zulässig.',
	'erreur_plugin_attribut_balise_manquant' => 'Attribut @attribut@ Fehlt in den Tag @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'Das Deinstallieren des Plugins ist fehlgeschlagen. Sie können es jedoch deaktivieren.',
	'erreur_plugin_fichier_absent' => 'Datei nicht vorhanden',
	'erreur_plugin_fichier_def_absent' => 'Definitionsdatei nicht vorhanden',
	'erreur_plugin_nom_fonction_interdit' => 'Unzulässiger Funktionsname',
	'erreur_plugin_nom_manquant' => 'Name des Plugin fehlt',
	'erreur_plugin_prefix_manquant' => 'Namespace des Plugin nicht definiert',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; fehlt in der Definitionsdatei',
	'erreur_plugin_version_manquant' => 'Version des Plugin fehlt',

	// H
	'htaccess_a_simuler' => 'Achtung: Ihr HTTP-Server ist so konfiguriert, daß er @htaccess@ Dateien ignoriert. Eine sichere Konfiguration des Servers erzielen sie, indem sie diese Einstellung ändern, oder indem sie die Konstanten  @constantes@ in der Datei mes_options.php so setzen, daß die Verzeichnisse außerhalb des @document_root@ liegen.',
	'htaccess_inoperant' => 'htaccess unwirksam',

	// I
	'ical_info1' => 'Diese Seite ermöglicht auf mehrere Arten an der Entwicklung der Website teilzunehmen.',
	'ical_info2' => 'Um mehr über diese Techniken zu erfahren, lesen Sie bitte die <a href="@spipnet@">SPIP Dokumentation</a>.',
	'ical_info_calendrier' => 'Sie verfügen über zwei Kalender. Einer gibt Ihnen eine Übersicht über die Website und alle dort veröffentlichten Artikel. Der zweite enthält editorische Ankündigungen und Ihre persönlichen Nachrichten. Sie allein haben Zugriff auf ihn indem Sie Ihr Passwort eingeben. Sie könne es ändern, indem Sie Ihr Zugangspasswort für diese Website ändern.',
	'ical_methode_http' => 'Download',
	'ical_methode_webcal' => 'Synchronisierung (webcal://)',
	'ical_texte_js' => 'Mit nur einer Zeile Javascript können Sie auf Ihrer Website die neuesten Artikel dieser Website anzeigen.',
	'ical_texte_prive' => 'Dieser nur für Sie selbst zugängliche Kalender hält Sie auf dem Laufenden über die internen redaktionellen Vorgänge dieser Website (Aufgaben und persönliche Termine, vorgeschlagene Artikel und Meldungen ...).',
	'ical_texte_public' => 'Dieser Kalender gibt Ihnen einen Überblick über die Ereignisse im öffentlichen Bereich der Website.',
	'ical_texte_rss' => 'Sie können die Neuheiten dieser Website mit einem beliebigen Programm anzeigen, dass das Format XML/RSS (Rich Site Summary) beherrscht. SPIP nutz dieses Protokoll auch, um neue Einträge aus anderen Websites zu übernehmen (sog. syndizierte Websites).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-List',
	'ical_titre_rss' => '"Backend" Datei',
	'icone_accueil' => 'Start',
	'icone_activer_cookie' => 'Verwaltungs-Cookie setzen',
	'icone_activite' => 'Aktivität',
	'icone_admin_plugin' => 'Plugin-Verwaltung',
	'icone_administration' => 'Wartung',
	'icone_afficher_auteurs' => 'Autoren anzeigen',
	'icone_afficher_visiteurs' => 'Besucher anzeigen',
	'icone_arret_discussion' => 'Aus dieser Diskussion aussteigen',
	'icone_calendrier' => 'Kalender',
	'icone_configuration' => 'Konfiguration',
	'icone_creer_auteur' => 'Neuen Autor anlegen und diesem Artikel zuordnen',
	'icone_creer_mot_cle' => 'Neues Schlagwort anlegen und mit diesem Artikel verknüpfen',
	'icone_creer_rubrique_2' => 'Neue Rubrik anlegen',
	'icone_developpement' => 'Entwicklung',
	'icone_edition' => 'Redaktion',
	'icone_ma_langue' => 'Meine Sprache',
	'icone_mes_infos' => 'Meine Informationen',
	'icone_mes_preferences' => 'Meine Einstellungen',
	'icone_modifier_article' => 'Artikel bearbeiten',
	'icone_modifier_rubrique' => 'Rubrik bearbeiten',
	'icone_publication' => 'Veröffentlichen',
	'icone_relancer_signataire' => 'Unterzeichner erneut benachrichtigen',
	'icone_retour' => 'Zurück',
	'icone_retour_article' => 'Zurück zum Artikel',
	'icone_squelette' => 'Skelette',
	'icone_suivi_publication' => 'Verlauf der Veröffentlichungen',
	'icone_supprimer_cookie' => 'Verwaltungs-Cookie löschen',
	'icone_supprimer_rubrique' => 'Rubrik löschen',
	'icone_supprimer_signature' => 'Unterschrift löschen',
	'icone_valider_signature' => 'Unterschrift bestätigen',
	'image_administrer_rubrique' => 'Sie können diese Rubrik verwalten',
	'info_1_article' => '1 Artikel',
	'info_1_auteur' => '1 Autor',
	'info_1_message' => '1 Nachricht',
	'info_1_mot_cle' => '1 Schlagwort',
	'info_1_rubrique' => '1 Rubrik',
	'info_1_visiteur' => '1 Besucher',
	'info_activer_cookie' => 'Sie können ein <b>Verwaltungs-Cookie</b> setzen. Es erlaubt Ihnen, Artikel und Rubriken direkt aus der Website zu bearbeiten.',
	'info_activer_menu_developpement' => 'Entwicklermenü anzeigen',
	'info_admin_etre_webmestre' => 'Mir Webmaster-Rechte geben',
	'info_admin_je_suis_webmestre' => 'Ich bin <b>Webmaster</b>',
	'info_admin_statuer_webmestre' => 'Diesem Administrator Webmaster-Rechte geben',
	'info_admin_webmestre' => 'Dieser Administrator ist <b>Webmaster</b>',
	'info_administrateur' => 'Administrator',
	'info_administrateur_1' => 'Administrator',
	'info_administrateur_2' => 'der Website (<i>vorsichtig einsetzen</i>)',
	'info_administrateur_site_01' => 'Wenn Sie Administrator der Website sind, bitte',
	'info_administrateur_site_02' => 'auf diesen Link klicken.',
	'info_administrateurs' => 'Administratoren',
	'info_administrer_rubrique' => 'Sie können diese Rubrik verwalten',
	'info_adresse' => 'an Adresse:',
	'info_adresse_desinscription' => 'Adresse für die Abmeldung:',
	'info_adresse_url' => 'Adresse (URL) der öffentlichen Website',
	'info_afficher_par_nb' => 'Anzeigen nach',
	'info_aide_en_ligne' => 'SPIP Online-Hilfe',
	'info_ajout_image' => 'Wenn Sie Bilder als Dokumente anlegen, die einem Artikel zugeordnet sind, kann SPIP automatisch (Miniatur-)Vorschaubilder dazu erstellen. Sie können so eine automatische Galerie oder Bildermappe einrichten.',
	'info_ajouter_rubrique' => 'Eine weitere zu verwaltende Rubrik hinzufügen:',
	'info_annonce_nouveautes' => 'Ankündigung der Neuigkeiten',
	'info_article' => 'Artikel',
	'info_article_2' => 'Artikel',
	'info_article_a_paraitre' => 'Vordatierte Artikel, die noch nicht erschienen sind.',
	'info_articles_02' => 'Artikel',
	'info_articles_2' => 'Artikel',
	'info_articles_auteur' => 'Alle Artikel dieses Autors',
	'info_articles_miens' => 'Meine Artikel',
	'info_articles_tous' => 'Alle Artikel',
	'info_articles_trouves' => 'Gefundene Artikel',
	'info_attente_validation' => 'Ihre zur Veröffentlichung vorgeschlagenen Artikel',
	'info_aucun_article' => 'Kein Artikel',
	'info_aucun_auteur' => 'Kein Autor',
	'info_aucun_message' => 'Keine Nachricht',
	'info_aucun_rubrique' => 'Keine Rubrik',
	'info_aujourdhui' => 'heute: ',
	'info_auteur_gere_rubriques' => 'Dieser Autor verwaltet folgende Rubriken :',
	'info_auteur_gere_toutes_rubriques' => 'Dieser Autor verwaltet <b>alle Rubriken</b>.',
	'info_auteur_gere_toutes_rubriques_2' => 'Ich verwalte <b>alle Rubriken</b>.',
	'info_auteurs' => 'Autoren',
	'info_auteurs_par_tri' => 'Autoren@partri@',
	'info_auteurs_trouves' => 'Gefundene Autoren',
	'info_authentification_externe' => 'Externe Authentifizierung',
	'info_avertissement' => 'Warnung',
	'info_barre_outils' => 'mit Symbolleiste?',
	'info_base_installee' => 'Die Struktur Ihrer Datenbank wurde angelegt.',
	'info_bio' => 'Biographie',
	'info_cache_desactive' => 'Der Cache ist vorübergehend deaktiviert.',
	'info_chapeau' => 'Kopf',
	'info_chapeau_2' => 'Kopf:',
	'info_chemin_acces_1' => 'Optionen: <b>Pfad im Verzeichnis</b>',
	'info_chemin_acces_2' => 'Sie müssen jetzt den Pfad zu den Informationen im Verzeichnis angeben. Diese Information ist unbedingt erforderlich, um die Benutzerprofile im Verzeichnis lesen zu können.',
	'info_chemin_acces_annuaire' => 'Optionen: <b>Pfad im Verzeichnis</b>',
	'info_choix_base' => 'Schritt 3: ',
	'info_classement_1' => ' von @liste@',
	'info_classement_2' => 'von @liste@',
	'info_code_acces' => 'Vergessen Sie ihre Zugangsdaten nicht!',
	'info_compatibilite_html' => 'Zu respektierende HTML Norm',
	'info_config_suivi' => 'Wenn es sich bei dieser Adresse um eine Mailing-Liste handelt, können Sie unten die Adresse angeben, unter der sich Teilnehmer der Website anmelden können. Es kann sich um den URL einer Webseite handeln (die ein Anmeldeformular enthält) oder um eine E-Mail Adresse mit angehängtem Parameter (z.B. <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Sie können die Mailing-Liste dieser Website abonnieren. Sie werden dann per E-Mail über neu zur Veröffentlichung vorgeschlagene Artikel informiert.',
	'info_confirmer_passe' => 'Neues Passwort bestätigen:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Achtung, die folgenden Felder wurden von anderen geändert. Ihre Änderungen in diesen Feldern wurden deshalb nicht gespeichert.',
	'info_conflit_edition_differences' => 'Unterschiede:',
	'info_conflit_edition_version_enregistree' => 'Die gespeicherte Fassung:',
	'info_conflit_edition_votre_version' => 'Ihre Fassung:',
	'info_connexion_base' => 'Test der Verbindung zur Datenbank',
	'info_connexion_base_donnee' => 'Verbindung mit Ihrer Datenbank',
	'info_connexion_ldap_ok' => 'Die LDAP-Verbindung wurde hergestellt.</b><p> Sie können mit dem nächsten Schritt fortfahren.</p>',
	'info_connexion_mysql' => 'Verbindung zur SQL-Datenbank',
	'info_connexion_ok' => 'Die Verbindung wurde hergestellt.',
	'info_contact' => 'Kontakt',
	'info_contenu_articles' => 'Inhalt der Artikel',
	'info_contributions' => 'Beiträge',
	'info_creation_paragraphe' => 'Um einen Absatz einzufügen, lassen Sie einfach eine Zeile frei.',
	'info_creation_rubrique' => 'Bevor Sie Artikel schreiben können,<br /> müssen Sie eine Rubrik anlegen.<br />',
	'info_creation_tables' => 'Anlegen der Datentabellen',
	'info_creer_base' => 'Neue Datenbank <b>anlegen</b>:',
	'info_dans_rubrique' => 'In der Rubrik:',
	'info_date_publication_anterieure' => 'Datum einer früheren Bearbeitung:',
	'info_date_referencement' => 'DATUM DER VERLINKUNG DIESER WEBSITE:',
	'info_derniere_etape' => 'Fertig!',
	'info_descriptif' => 'Beschreibung:',
	'info_desinstaller_plugin' => 'löscht die Daten und desktiviert das Plugin',
	'info_discussion_cours' => 'Aktuelle Diskussionen',
	'info_ecrire_article' => 'Bevor Sie Artikel schreiben könnnen, müssen Sie mindestens eine Rubrik anlegen.',
	'info_email_envoi' => 'Absenderadresse (freiwillige Angabe)',
	'info_email_envoi_txt' => 'Geben Sie hier die Absenderadresse der E-Mails an (ohne diese Angabe wird die Empfängeradresse als Absender eingetragen). ',
	'info_email_webmestre' => 'E-Mail des Webmasters',
	'info_envoi_email_automatique' => 'Automatischer Mailversand',
	'info_envoyer_maintenant' => 'Jetzt schicken',
	'info_etape_suivante' => 'Weiter',
	'info_etape_suivante_1' => 'Sie können den nächsten Schritt ausführen.',
	'info_etape_suivante_2' => 'Sie können den nächsten Schritt ausführen.',
	'info_exceptions_proxy' => 'Ausnahmen für den Proxy',
	'info_exportation_base' => 'Export der Datenbank nach @archive@',
	'info_facilite_suivi_activite' => 'Um die editorische Arbeit zu erleichtern kann SPIP Veröffentlichungsvorschläge und Freischaltungen z.B. an eine Mailing-Liste der Redakteure schicken.',
	'info_fichiers_authent' => '“.htpasswd” Dateien',
	'info_forums_abo_invites' => 'Ihre Website hat Foren für eingetragene Teilnehmer. Ihre Leser werden aus diesem Gund aufgefordert, sich bei Ihrer Website anzumelden.',
	'info_gauche_admin_tech' => '<b>Diese Seite ist nur für den Verantwortlichen der Website zugänglich.</b><p>Sie erlaubt bestimmte technische Wartungsvorgänge auszulösen. Für manche Funktionen ist die Authentifizierung per FTP Voraussetzung.',
	'info_gauche_admin_vider' => '<b>Diese Seite ist nur für den Verantwortlichen der Website zugänglich.</b><p>Sie erlaubt bestimmte technische Wartungsvorgänge auszulösen. Für manche Funktionen ist die Authentifizierung per FTP Voraussetzung.',
	'info_gauche_auteurs' => 'Hier sehen Sie alle Autoren der Website.
Ihr Status wird durch die Farbe ihres Symbols angezeigt (Redakteur = gelb; Administrator = grün). ',
	'info_gauche_auteurs_exterieurs' => 'Externe Autoren ohne Zugang zum Redaktionssystem werden mit einem blauen Symbol gekennzeichnet, gelöschte Autoren haben eine Mülltonne als Symbol.',
	'info_gauche_messagerie' => 'Nachrichtensystem: SPIP ermöglicht den Austausch von Nachrichten zwischen Redakteuren, persönliche Merkzettel und Ankündigungen im privaten Arbeitsbereich der Redakteure (nur Administratoren können diese verschicken).',
	'info_gauche_statistiques_referers' => 'Diese Seite zeigt Ihnen <i>REFERER</i>, d.h. Webadressen mit Links zu Ihrer Website. Angezeigt werden nur Links von gestern und heute, diese Liste wird alle 24 Stunden auf Null gesetzt.',
	'info_gauche_visiteurs_enregistres' => 'Hier sehen Sie die im öffentlichen Bereich der Website angemeldeten Besucher (Teilnahme an Foren nur mit gültiger E-Mail Adresse).',
	'info_generation_miniatures_images' => 'Anlegen der Vorschaubilder',
	'info_gerer_trad_objets' => '@objets@: Übersetzungslinks verwalten',
	'info_hebergeur_desactiver_envoi_email' => 'Manche ISPs verhindern den Versand von Mails mit PHP. Die Mailfunktionen von SPIP funktionieren dann nicht.',
	'info_hier' => 'Gestern:',
	'info_identification_publique' => 'Ihre öffentliche Identität ...',
	'info_image_process' => 'Bitte wählen Sie das beste Verfahren zum Generieren der Miniaturbilder, indem Sie auf ein Bild klicken.',
	'info_image_process2' => 'Wenn kein Bild angezeigt wird, ist der Server ihrer Website nicht für die Verwendung solcher Werkzeuge eingerichtet. Wenn Sie diese Funktionen nutzen möchten, wenden Sie sich bitte an den verantwortlichen Techniker und bitten ihn, die Erweiterungen «GD» oder «Imagick» einzurichten.',
	'info_images_auto' => 'automatisch berechnete Bilder',
	'info_informations_personnelles' => 'Persönliche Informationen',
	'info_inscription' => 'Angemeldet am',
	'info_inscription_automatique' => 'Automatische Anmeldung neuer Redakteure',
	'info_jeu_caractere' => 'Zeichensatz der Website',
	'info_jours' => 'Tage',
	'info_laisser_champs_vides' => 'diese Felder frei lassen)',
	'info_langues' => 'Sprachen der Website',
	'info_ldap_ok' => 'Die LDAP-Authentifizierung ist installiert.',
	'info_lien_hypertexte' => 'Hyperlink:',
	'info_liste_nouveautes_envoyee' => 'Die Liste der Neuerscheinungen wurde versand.',
	'info_liste_redacteurs_connectes' => 'Liste der zur Zeit angemeldeten Redakteure',
	'info_login_existant' => 'Dieses Login ist bereits vergeben.',
	'info_login_trop_court' => 'Login zu kurz.',
	'info_login_trop_court_car_pluriel' => 'Ihr Login muss mindestens @nb@ Zeichen haben.',
	'info_logos' => 'Die Logos',
	'info_maximum' => 'Maximum:',
	'info_meme_rubrique' => 'In der gleichen Rubrik',
	'info_message_en_redaction' => 'IHRE NACHRICHTEN IN BEARBEITUNG',
	'info_message_technique' => 'Technische Nachricht:',
	'info_messagerie_interne' => 'Interne Nachrichten',
	'info_mise_a_niveau_base' => 'Update Ihrer SQL-Datenbank',
	'info_mise_a_niveau_base_2' => '{{ACHTUNG!}} Sie haben eine {ältere} Version der SPIP-Dateien installiert als sich vorher auf Ihrem Server befand. Ihre Datenbank wird möglicherweise zerstört und Ihre Website wird nict mehr funktionieren.<br />{{Installieren Sie SPIP noch einmal.}}',
	'info_modification_enregistree' => 'Ihre Änderung wurde gespeichert.',
	'info_modifier_auteur' => 'Autor bearbeiten:',
	'info_modifier_rubrique' => 'Rubrik bearbeiten:',
	'info_modifier_titre' => 'Bearbeiten: @titre@',
	'info_mon_site_spip' => 'Meine SPIP-Site',
	'info_moyenne' => 'Durchschnitt: ',
	'info_multi_cet_article' => 'Dieser Artikel ist auf: ',
	'info_multi_langues_choisies' => 'Bitte wählen Sie hier die Sprachen aus, die den Redakteuren Ihrer Website zur Verfügung stehen sollen. Die Sprachen, welche bereits in Ihrer Website verwendet werden (oben auf der Liste), können nicht abgeschaltet werden.',
	'info_multi_objets' => '@objets@: Sprachauswahlmenü aktivieren',
	'info_multi_secteurs' => '... nur für Rubriken der obersten Ebene?',
	'info_nb_articles' => '@nb@ Artikel',
	'info_nb_auteurs' => '@nb@ Autoren',
	'info_nb_messages' => '@nb@ Nachrichten',
	'info_nb_mots_cles' => '@nb@ Schlagworte',
	'info_nb_rubriques' => '@nb@ Rubriken',
	'info_nb_visiteurs' => '@nb@ Besucher',
	'info_nom' => 'Name',
	'info_nom_destinataire' => 'Name des Empfängers',
	'info_nom_pas_conforme' => 'HTNL-Tags sind nicht zugelassen.',
	'info_nom_site' => 'Name Ihrer Website',
	'info_nombre_articles' => '@nb_articles@ Artikel,',
	'info_nombre_rubriques' => '@nb_rubriques@ Rubriken, ',
	'info_nombre_sites' => '@nb_sites@ Websites, ',
	'info_non_deplacer' => 'Bitte nicht verschieben...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP kann regelmäßig die letzten Neuigkeiten der Website verschicken. (vor Kurzem erschienene Artikel und Meldungen).',
	'info_non_envoi_liste_nouveautes' => 'Keine Liste der Neuigkeiten verschicken.',
	'info_non_modifiable' => 'kann nicht geändert werden.',
	'info_non_suppression_mot_cle' => 'ich möchte dieses Schlagwort nicht löschen.',
	'info_notes' => 'Anmerkungen', # Fußnoten bzw. #NOTES werden besser als "Anmerkungen" denn als "Notizen" bezeichnet.
	'info_nouvel_article' => 'Neuer Artikel',
	'info_nouvelle_traduction' => 'Neue Übersetzung:',
	'info_numero_article' => 'ARTIKEL NUMMER:',
	'info_obligatoire_02' => ' (Erforderlich)',
	'info_option_accepter_visiteurs' => 'Besucher dürfen sich als Leser der Website anmelden.',
	'info_option_ne_pas_accepter_visiteurs' => 'Anmeldung von Lesern verhindern',
	'info_options_avancees' => 'SPEZIALFUNKTIONEN',
	'info_ou' => 'oder ... ',
	'info_page_interdite' => 'Seite gesperrt',
	'info_par_nom' => 'nach Namen',
	'info_par_nombre_article' => 'nach Anzahl der Artikel',
	'info_par_statut' => 'nach Status',
	'info_par_tri' => '’(nach @tri@)’',
	'info_passe_trop_court' => 'Passwort zu kurz.',
	'info_passe_trop_court_car_pluriel' => 'Das Passwort muss mindestens @nb@ Zeichen haben.',
	'info_passes_identiques' => 'Die zwei Passworte stimmen nicht überein.',
	'info_plus_cinq_car' => 'mehr als 5 Zeichen',
	'info_plus_cinq_car_2' => '(mehr als 5 Zeichen)',
	'info_plus_trois_car' => '(mehr als 3 Zeichen)',
	'info_popularite' => 'Beliebtheit: @popularite@ ; Besuche: @visites@',
	'info_post_scriptum' => 'Post-Scriptum',
	'info_post_scriptum_2' => 'Post-scriptum:',
	'info_pour' => 'für',
	'info_preview_texte' => 'Man kann sich alle Elemente der Website so anzeigen lassen, als ob sie veröffentlicht wären, vorausgesetzt sie haben mindestens den Status « vorgeschlagen » oder man ist ihr Autor . Wem soll diese Möglichkeit zur Verfügung stehen (Adminsitratoren, Redakteure, niemand)?',
	'info_procedez_par_etape' => 'gehen Sie Schritt für Schritt vor',
	'info_procedure_maj_version' => 'Sie müssen die Update-Funktion starten, um Ihre Datenbank an die neue Version von SPIP anzupassen.',
	'info_proxy_ok' => 'Proxytest erfolgreich.',
	'info_ps' => 'P.S.',
	'info_publier' => 'veröffentlichen',
	'info_publies' => 'Ihre veröffentlichten Artikel',
	'info_question_accepter_visiteurs' => 'Bitte aktivieren Sie die folgende Option, wenn sich Besucher Ihrer Website als <i>Leser ohne Zugang zum Redaktionssystem</i> anmelden können.',
	'info_question_inscription_nouveaux_redacteurs' => 'Möchten Sie, dass sich neue Redakteure vom öffentlichen Bereich
 aus anmelden können? Wenn Sie es wollen, können sich Besucher über ein automatisch
 erstelltes Formular anmelden und Artikel vorschlagen.
 <div class="notice">Nach der Anmeldung erhalten die neuen Redakteure automatisch
 eine E-Mail mit ihren Zugangsdaten. Manche Webhoster unterbinden den Mailversand
 von ihren Webservern aus.
 In diesem Fall funktioniert die automatische Anmeldung nicht.</div>',
	'info_qui_edite' => '@nom_auteur_modif@ hat vor  @date_diff@ Minuten an diesem Objekt gearbeitet.',
	'info_racine_site' => 'OBERSTE EBENE DER WEBSITE',
	'info_recharger_page' => 'Bitte laden Sie diese Seite in ein paar Augenblicken erneut.',
	'info_recherche_auteur_zero' => 'Dem Kriterium “@cherche_auteur@” entspricht kein Autor.',
	'info_recommencer' => 'Bitte wiederholen.',
	'info_redacteur_1' => 'Redakteur',
	'info_redacteur_2' => 'mit Zugang zum Redaktionssystem (<i>empfohlen</i>)',
	'info_redacteurs' => 'Redakteure',
	'info_redaction_en_cours' => 'IN BEARBEITUNG',
	'info_redirection' => 'Umleitung',
	'info_redirection_activee' => 'Die Weiterleitung ist aktiviert.',
	'info_redirection_boucle' => 'Sie versuchen, den Artikel mit sich selber zu verlinken.',
	'info_redirection_desactivee' => 'Die Weiterleitung wurde abgeschaltet.',
	'info_refuses' => 'Ihre abgelehnten Artikel',
	'info_reglage_ldap' => 'Optionen: <b>LDAP-Import Einstellungen</b>',
	'info_renvoi_article' => '<b>Umleitung.</b> Dieser Artikel zeigt auf die Seite: ',
	'info_reserve_admin' => 'Nur Administratoren können diese Seite ändern.',
	'info_restreindre_rubrique' => 'Administrationsrechte auf diese Rubrik beschränken:',
	'info_resultat_recherche' => 'Suchergebnisse:',
	'info_rubriques' => 'Rubriken',
	'info_rubriques_02' => 'Rubriken',
	'info_rubriques_trouvees' => 'Rubriken gefunden',
	'info_sans_titre' => 'Ohne Titel',
	'info_selection_chemin_acces' => '<b>Wählen Sie</b> hier den Pfad zu Ihrem Verzeichnis:',
	'info_signatures' => 'Unterschriften',
	'info_site' => 'Website',
	'info_site_2' => 'Website: ',
	'info_site_min' => 'Website',
	'info_site_reference_2' => 'Verlinkte Website',
	'info_site_web' => 'Website:',
	'info_sites' => 'Websites',
	'info_sites_lies_mot' => 'Mit dieser Website verknüpfte Schlagworte',
	'info_sites_proxy' => 'HTTP-Proxy verwenden',
	'info_sites_trouves' => 'Gefundene Websites',
	'info_sous_titre' => 'Untertitel:',
	'info_statut_administrateur' => 'Administrator',
	'info_statut_auteur' => 'Status des Autors:',
	'info_statut_auteur_2' => 'Ich bin',
	'info_statut_auteur_a_confirmer' => 'Anmeldung bestätigen',
	'info_statut_auteur_autre' => 'Anderer Status:',
	'info_statut_redacteur' => 'Redakteur',
	'info_statut_utilisateurs_1' => 'Vorgegebener Status der importierten Benutzer',
	'info_statut_utilisateurs_2' => 'Wählen Sie den Status, der Personen im LDAP-Verzeichnis zugeordnet wird, wenn sie sich zum ersten Mal anmelden. Sie können diesen Wert später für jeden Autor individuell einstellen.',
	'info_suivi_activite' => 'Unterstützung der Redaktionsabläufe',
	'info_surtitre' => 'Einleitender Titel:',
	'info_syndication_integrale_1' => 'Ihre Website biete Backend-Dateien zur Syndikation an (siehe « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Möchten sie den gesamten Text der Artikel überragen oder nur eine Zusammenfassung von ein paar hundert Zeichen?',
	'info_table_prefix' => 'Sie können den ersten Teil (das Prefix) der Datentabellen ändern. Das ist unerlässlich, wenn sie mehrere Websites in der selben Datenbank speichern möchten. Das Prefix besteht aus kleinen Buchstaben ohne Akzente, Sonder- oder Leerzeichen',
	'info_taille_maximale_images' => 'SPIP wird die maximale Größe der Bilder (in Millionen Pixel) testen, die es bearbeiten kann.<br /> Größere Bilder werden nicht verkleinert.',
	'info_taille_maximale_vignette' => 'Maximale Grösse der Icons des Systems:',
	'info_terminer_installation' => 'Sie können jetzt die Standardinstallation abschliessen.',
	'info_texte' => 'Text',
	'info_texte_explicatif' => 'Beschreibung',
	'info_texte_long' => '(Das ist ein langer Text. Er wird in mehreren Teilen angezeigt, die nach der Veröffentlichung zusammen gefügt werden.)',
	'info_texte_message' => 'Text Ihrer Nachricht',
	'info_texte_message_02' => 'Text Ihrer Nachricht',
	'info_titre' => 'Titel:',
	'info_total' => 'Gesamt: ',
	'info_tous_articles_en_redaction' => 'Alle Artikel in Bearbeitung',
	'info_tous_articles_presents' => 'Alle veröffentlichten Artikel dieser Rubrik',
	'info_tous_articles_refuses' => 'Alle abgelehnten Artikel',
	'info_tous_les' => 'alle',
	'info_tout_site' => 'Ganze Website',
	'info_tout_site2' => 'Der Artikel wurde nicht in diese Sprache übersetzt.',
	'info_tout_site3' => 'Der Artikel wurde in diese Sprache übersetzt, aber der Originalartikel wurde erneut verändert. Die Übersetzung muss überarbeitet werden.',
	'info_tout_site4' => 'Der Artikel wurde in diese Sprache übersetzt und die Übersetzung ist aktuel.',
	'info_tout_site5' => 'Originalartikel.',
	'info_tout_site6' => '<b>Achtung:</b> Nur die Originalartikel werden aufgelistet..
Die Übersetzungen entsprechen dem Original,
in einer Farbe, die den Status anzeigt :',
	'info_traductions' => 'Übersetzungen',
	'info_travail_colaboratif' => 'Gemeinsame Arbeit an den Artikeln',
	'info_un_article' => ' ein Artikel, ',
	'info_un_site' => ' eine Website, ',
	'info_une_rubrique' => ' eine Rubrik, ',
	'info_une_rubrique_02' => '1 Rubrik',
	'info_url' => 'URL:',
	'info_url_proxy' => 'URL des Proxy',
	'info_url_site_pas_conforme' => 'Ungültiger Website-URL',
	'info_url_test_proxy' => 'Test-URL',
	'info_urlref' => 'Hyperlink:',
	'info_utilisation_spip' => 'Sie können SPIP jetzt verwenden ...',
	'info_visites_par_mois' => 'Anzeige pro Monat:',
	'info_visiteur_1' => 'Besucher',
	'info_visiteur_2' => 'des öffentlichen Bereichs',
	'info_visiteurs' => 'Besucher',
	'info_visiteurs_02' => 'Besucher des öffentlichen Bereichs',
	'info_webmestre_forces' => 'Die Webmaster sind in der Datei <tt>@file_options@</tt> konfiguriert.',
	'install_adresse_base_hebergeur' => 'Adresse der vom Provider zugewiesenen Datenbank',
	'install_connect_ok' => 'Die neue Datenbank wurde unter dem Namen @connect@ deklariert.',
	'install_echec_annonce' => 'Die Installation wird wahrscheinlich fehlschlagen oder eine nicht funktionierende Site ergeben.',
	'install_extension_mbstring' => 'SPIP funktioniert nicht mit:',
	'install_extension_php_obligatoire' => 'SPIP benötigt die Dateierweiterung php:',
	'install_login_base_hebergeur' => 'Vom Provider zugeteiltes Login',
	'install_nom_base_hebergeur' => 'Name der vom Provider zugewiesenen Datenbank:',
	'install_pas_table' => 'Datenbank zur Zeit ohne Tabellen',
	'install_pass_base_hebergeur' => 'Vom Provider zugeteiltes Passwort',
	'install_php_version' => 'Die PHP-Version @version@ ist zu alt. (Mindestens erforderlich = @minimum@)',
	'install_select_langue' => 'Wählen Sie eine Sprache aus und klicken Sie auf «Weiter», um die Installation zu starten.',
	'install_select_type_db' => 'Geben Sie den Typ der Datenbank an:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Vom Provider bereitgestellter Datenbankserver',
	'install_table_prefix_hebergeur' => 'Prefix der vom Provider zugeteilten Tabelle',
	'install_tables_base' => 'Tabellen der Datenbank',
	'install_types_db_connus' => 'SPIP beherrscht <b>MySQL</b> (am weitesten verbreitet) und  <b>SQLite</b>.', # Geht PostGreSQL jetzt nicht mehr?
	'install_types_db_connus_avertissement' => '<b>PostgreSQL</b> wird testweise unterstützt.',
	'instituer_erreur_statut_a_change' => 'Der Status wurde bereits geändert.',
	'instituer_erreur_statut_non_autorise' => 'Sie dürfen diesen Status nicht auswählen.',
	'intem_redacteur' => 'Redakteur',
	'intitule_licence' => 'Lizenz',
	'item_accepter_inscriptions' => 'Anmeldungen erlauben',
	'item_activer_messages_avertissement' => 'Aktuelle Benachrichtigungen einschalten',
	'item_administrateur_2' => 'Administrator',
	'item_afficher_calendrier' => 'Im Kalender anzeigen',
	'item_autoriser_syndication_integrale' => 'Vollständige Artikel im Feed übertragen',
	'item_choix_administrateurs' => 'Administratoren',
	'item_choix_generation_miniature' => 'Vorschaubilder automatisch generieren.',
	'item_choix_non_generation_miniature' => 'Keine Vorschaubilder generieren.',
	'item_choix_redacteurs' => 'Redakteure',
	'item_choix_visiteurs' => 'Besucher im öffentlichen Bereich',
	'item_creer_fichiers_authent' => '.htpasswd-Dateien anlegen',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Nachrichtenfunktion des Kalenders aktivieren',
	'item_mots_cles_association_articles' => 'Artikeln zuordnen',
	'item_mots_cles_association_rubriques' => 'Rubriken zuordnen',
	'item_mots_cles_association_sites' => 'syndizierten Websites zuordnen.',
	'item_non' => 'Nein',
	'item_non_accepter_inscriptions' => 'Anmeldungen verhindern',
	'item_non_activer_messages_avertissement' => 'Keine aktuellen Benachrichtigungen',
	'item_non_afficher_calendrier' => 'Nicht im Kalender anzeigen',
	'item_non_autoriser_syndication_integrale' => 'Nur Zusammenfassung übertragen',
	'item_non_creer_fichiers_authent' => 'Diese Dateien nicht anlegen',
	'item_non_messagerie_agenda' => 'Nachrichtenfunktion des Kalenders abschalten',
	'item_non_publier_articles' => 'Artikel nicht vor dem eingestellten Datum veröffentlichen.',
	'item_nouvel_auteur' => 'Neuer Autor',
	'item_nouvelle_rubrique' => 'Neue Rubrik',
	'item_oui' => 'Ja',
	'item_publier_articles' => 'Sofort veröffentlichen, egal welches Datum ein Artikel trägt. ',
	'item_reponse_article' => 'Antwort auf Artikel',
	'item_version_html_max_html4' => 'Im öffentlichen bereich nur HTML4 verwenden',
	'item_version_html_max_html5' => 'HTML5 erlauben',
	'item_visiteur' => 'Besucher',

	// J
	'jour_non_connu_nc' => 'unbekannt',

	// L
	'label_bando_outils' => 'Werkzeugleiste',
	'label_bando_outils_afficher' => 'Werkzeuge anzeigen',
	'label_bando_outils_masquer' => 'Werkzeuge ausblenden',
	'label_choix_langue' => 'Ihre Sprache wählen',
	'label_nom_fichier_connect' => 'Geben Sie den für diesen Server verwendeten Namen an.',
	'label_slogan_site' => 'Slogan der Website',
	'label_taille_ecran' => 'Bildschirmbreite',
	'label_texte_et_icones_navigation' => 'Navigationsmenü',
	'label_texte_et_icones_page' => 'Auf der Seite anzeigen',
	'ldap_correspondance' => 'Vererbung von Feld @champ@',
	'ldap_correspondance_1' => 'Vererbung des LDAP Felds',
	'ldap_correspondance_2' => 'Geben sie bitte für jedes der folgenden SPIP-Felder das entsprechende LDAP-Feld an. Leere Felder werden nicht genutzt, LDAP-Felder mit Leerzeichen oder Kommata trennen, um mehrere zu probieren. ',
	'lien_ajouter_auteur' => 'Autor hinzufügen',
	'lien_ajouter_une_rubrique' => 'Diese Rubrik hinzufügen',
	'lien_email' => 'E-Mail',
	'lien_nom_site' => 'NAME DER WEBSITE:',
	'lien_retirer_auteur' => 'Autor entfernen',
	'lien_retirer_rubrique' => 'Rubrik entfernen',
	'lien_retirer_tous_auteurs' => 'Alle Autoren entfernen',
	'lien_retirer_toutes_rubriques' => 'Alle Rubriken entfernen ',
	'lien_site' => 'Website',
	'lien_tout_decocher' => 'Alles abwählen',
	'lien_tout_deplier' => 'Alle anzeigen',
	'lien_tout_replier' => 'Alle ausblenden',
	'lien_tout_supprimer' => 'Alles löschen',
	'lien_trier_nom' => 'Nach Namen sortieren',
	'lien_trier_nombre_articles' => 'Nach Zahl der Artikel sortieren',
	'lien_trier_statut' => 'Nach Status sortieren',
	'lien_voir_en_ligne' => 'ONLINE ANZEIGEN:',
	'logo_article' => 'Artikel-Logo',
	'logo_auteur' => 'Autoren-Logo',
	'logo_rubrique' => 'Rubrik-Logo',
	'logo_site' => 'Website-Logo',
	'logo_standard_rubrique' => 'Standardlogo für Rubriken',
	'logo_survol' => 'Mouseover-Logo',

	// M
	'menu_aide_installation_choix_base' => 'Datenbank auswählen',
	'module_fichier_langue' => 'Sprachdatei',
	'module_raccourci' => 'Abkürzung',
	'module_texte_affiche' => 'angezeigter Text',
	'module_texte_explicatif' => 'Sie können die folgenden Abkürzungen in den HTML-Vorlagen Ihrer Website verwenden. Sie werden automatisch in den Sprachen angezeigt, für die eine Sprachdatei existiert.',
	'module_texte_traduction' => 'Die Sprachdatei für « @module@ » liegt vor auf ',
	'mois_non_connu' => 'unbekannt',

	// N
	'nouvelle_version_spip' => 'SPIP Version @version@ ist verfügbar.',
	'nouvelle_version_spip_majeure' => 'Eine neue SPIP Version @version@ steht zur Verfügung.',

	// O
	'onglet_contenu' => 'Inhalt',
	'onglet_declarer_une_autre_base' => 'Weitere Datenbank deklarieren',
	'onglet_discuter' => 'Diskussionen',
	'onglet_interactivite' => 'Interaktivität',
	'onglet_proprietes' => 'Eigenschaften',
	'onglet_repartition_actuelle' => 'zur Zeit',
	'onglet_sous_rubriques' => 'Unterrubriken',

	// P
	'page_pas_proxy' => 'Diese Seite darf nicht durch den Proxy übertragen werden.',
	'pas_de_proxy_pour' => 'Falls erforderlich, könne Sie die Rechner und Domainen angeben, die nicht über den Proxy angesprochen werden (z.B. @exemple@)',
	'plugin_charge_paquet' => 'Paket @name@ wird geladen',
	'plugin_charger' => 'Übertragen',
	'plugin_erreur_charger' => 'Fehler: @zip@ kann nicht geladen werden',
	'plugin_erreur_droit1' => 'In das Verzeichnis <code>@dest@</code> kann nicht geschrieben werden.',
	'plugin_erreur_droit2' => 'Bitte überprüfen Sie die Schreibrechte für dieses Verzeichnis oder legen Sie es an, falls es noch nicht existiert, oder installieren Sie die Dateien per FTP.',
	'plugin_erreur_zip' => 'Pclzip fehlgeschlagen: Fehler @status@',
	'plugin_etat_developpement' => 'In Entwicklung',
	'plugin_etat_experimental' => 'Experimentell',
	'plugin_etat_stable' => 'Stabil',
	'plugin_etat_test' => 'Im Test',
	'plugin_impossible_activer' => 'Das Plugin @plugin@ kann nicht aktiviert werden.',
	'plugin_info_automatique1' => 'Wenn Sie die automatische Installation von Plugins nutzen möchten, führen Sie bitte folgende Schritte aus:',
	'plugin_info_automatique1_lib' => 'Wenn diese Bibliothek automatisch installiert werden soll, führen sie bitte diese Schritte aus:',
	'plugin_info_automatique2' => 'Anlegen des Verzeichnis <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'überprüfen, ob der Server in das Verzeichnis schreiben kann.',
	'plugin_info_automatique_creer' => 'im Wurzelverzeichnis der Website.',
	'plugin_info_automatique_exemples' => 'Beispiele:',
	'plugin_info_automatique_ftp' => 'Sie können Plugins per FTP in dem Vezeichnis <tt>@rep@</tt> installieren',
	'plugin_info_automatique_lib' => 'Manche Plugins benötigen das Verzeichnis <code>lib/</code>, um Dateien downloaden zu können, das im Wurzelverzeichnis der Website angelegt werden muss.',
	'plugin_info_automatique_liste' => 'Ihre Plugin-Listen:',
	'plugin_info_automatique_liste_officielle' => 'Die offiziellen Plugins',
	'plugin_info_automatique_liste_update' => 'Listen aktualisieren',
	'plugin_info_automatique_ou' => 'oder...',
	'plugin_info_automatique_select' => 'Wählen Sie ein Plugin aus. SPIP wird es herunterladen und im Verzeichnis <code>@rep@</code> installieren. Falls das Plugin bereits installiert ist, wird es auf den neuesten Stand gebracht.',
	'plugin_info_credit' => 'Beteiligte',
	'plugin_info_erreur_xml' => 'Die Deklaration dieses Plugins ist nicht korrekt.',
	'plugin_info_install_ok' => 'Installation war erfolgreich.',
	'plugin_info_necessite' => 'Erfordert:',
	'plugin_info_non_compatible_spip' => 'Dieses Plugin ist nicht mit SPIP kompatibel.',
	'plugin_info_plugins_dist_1' => 'Diese Erweiterungen liegen im Verzeichnis @plugins_dist@ und werden dort aktiviert.',
	'plugin_info_plugins_dist_2' => 'Man kann sie nicht deaktivieren.',
	'plugin_info_telecharger' => 'herunterladen von @url@ und in @rep@ installieren',
	'plugin_info_upgrade_ok' => 'Upgrade erfolgreich',
	'plugin_librairies_installees' => 'Installierte Bibliotheken',
	'plugin_necessite_lib' => 'Dieses Plugin benötigt die Bibliothek @lib@',
	'plugin_necessite_plugin' => 'Benötigt Version @version@ des Plugin @plugin@.',
	'plugin_necessite_plugin_sans_version' => 'Benötigt das Plugin @plugin@',
	'plugin_necessite_spip' => 'Benötigt mindestens Version @version@ von SPIP.',
	'plugin_source' => 'Quelle: ',
	'plugin_titre_automatique' => 'Automatische Installation',
	'plugin_titre_automatique_ajouter' => 'Plugins hinzufügen',
	'plugin_titre_installation' => 'Installation des Plugins @plugin@',
	'plugin_titre_modifier' => 'Meine Plugins',
	'plugin_utilise_plugin' => 'Verwendet das Plugin @plugin@ in der Version @version@.',
	'plugin_zip_active' => 'Weiter zum Aktivieren',
	'plugin_zip_adresse' => 'Geben Sie hier die Adresse einer ZIP-Datei, die das Plugin enthält, oder die Adresse einer Plugin-Liste an.',
	'plugin_zip_adresse_champ' => 'Adresse des Plugins oder der Liste ',
	'plugin_zip_content' => 'Enthält die folgenden Dateien (@taille@),<br />die im Verzeichnis <code>@rep@</code> installiert werden können.',
	'plugin_zip_installe_finie' => 'Die Datei @zip@ wurde entpackt und installiert.',
	'plugin_zip_installe_rep_finie' => 'Die Datei @zip@ wurde entpackt und in das Verzeichnis @rep@ installiert.',
	'plugin_zip_installer' => 'Sie können es jetzt installieren.',
	'plugin_zip_telecharge' => 'Die Datei @zip@ wurde heruntergeladen',
	'plugins_actif_aucun' => 'Kein aktives Plugin.',
	'plugins_actif_un' => 'Ein aktives Plugin.',
	'plugins_actifs' => '@count@ aktive Plugins.',
	'plugins_actifs_liste' => 'Aktiv',
	'plugins_compte' => '@count@ Plugins',
	'plugins_disponible_un' => 'Ein Plugin verfügbar.',
	'plugins_disponibles' => '@count@ verfügbare Plugins.',
	'plugins_erreur' => 'Fehler in den Plugins: @plugins@',
	'plugins_liste' => 'Installierte Plugins',
	'plugins_liste_dist' => 'Gesicherte Plugins', # Das hat jetzt aber mit plugins_liste_dist nichts mehr zu tun.
	'plugins_recents' => 'Neueste Plugins.',
	'plugins_tous_liste' => 'Alle',
	'plugins_vue_hierarchie' => 'Hierarchie',
	'plugins_vue_liste' => 'Liste',
	'protocole_ldap' => 'Version des Protokolls:',

	// Q
	'queue_executer_maintenant' => 'Jetzt ausführen',
	'queue_info_purger' => 'Sie können alle anstehenden Jobs löschen und so die Liste der regelmäßigen Jobs neu initialisieren.',
	'queue_nb_jobs_in_queue' => '@nb@ Jobs in der Warteschlange',
	'queue_next_job_in_nb_sec' => 'Nächster Job in @nb@ s',
	'queue_no_job_in_queue' => 'Keine Aufgaben in der Warteschlange',
	'queue_one_job_in_queue' => '1 Job in der Warteschlange',
	'queue_purger_queue' => 'Jobliste löschen',
	'queue_titre' => 'Jobliste',

	// R
	'repertoire_plugins' => 'Verzeichnis:',
	'required' => ' (Erforderlich)',

	// S
	'sans_heure' => 'Ohne Zeit',
	'statut_admin_restreint' => 'Rubrik-Admin',
	'statut_webmestre' => 'Webmaster',

	// T
	'tache_cron_asap' => 'Cronjob @function@ (unverzüglich)',
	'tache_cron_secondes' => 'Cronjob @function@ (alle @nb@ Sekunden)',
	'taille_cache_image' => 'Die von SPIP automatisch berechneten Grafiken (Icons für Dokumente, als Grafiken gespeicherte Titel, mathematische Ausdrücke im Format TeX...) belegen insgesamt @taille@ im Verzeichnis @dir@.',
	'taille_cache_infinie' => 'Die Grösse des <code>CACHE/</code> dieser Website wird nicht begrenzt.',
	'taille_cache_maxi' => 'SPIP versucht die Grösse des <code>CACHE/</code> der Website auf ca. <b>@octets@</b> Byte zu begrenzen.',
	'taille_cache_moins_de' => 'Die Größe des Caches beträgt mindestens  @octets@.',
	'taille_cache_octets' => 'Aktuelle Grösse des Cache: @octets@ Byte',
	'taille_cache_vide' => 'Der Cache ist leer.',
	'taille_repertoire_cache' => 'Grösse des Cache-Verzeichnis',
	'text_article_propose_publication' => 'Dieser Artikel ist zur Veröffentlichung vorgeschlagen.',
	'texte_acces_ldap_anonyme_1' => 'Manche LDAP-Server erlauben keinen anonymen Zugriff. In diesem Fall muss man Zugangsdaten für die erste Anmeldung eingeben, um Informationen im Verzeichnis suchen zu können. Meistens kann man hingegen die folgenden Felder frei lassen.',
	'texte_admin_effacer_01' => 'Dieser Befehl löscht den <i>gesamten</i> Inhalt der Datenbank mit <i>allen</i> Redakteuren und Administratoren. Nach der Ausführung dieses Befehls müssen Sie SPIP neu installieren und einen ersten Administrator anlegen.',
	'texte_adresse_annuaire_1' => '(Wenn Ihr Verzeichnis auf dem selben Rechner installiert ist wie diese Website, müssen Sie wahrscheinlich „localhost“ angeben.)',
	'texte_ajout_auteur' => 'Folgender Autor ist diesem Artikel zugeordnet worden:',
	'texte_annuaire_ldap_1' => 'Wenn Sie Zugang zu einem LDAP-Verzeichnis haben, können Sie es verwenden, um Benutzer automatisch nach SPIP zu importieren.',
	'texte_article_statut' => 'Dieser Artikel ist:',
	'texte_article_virtuel' => 'Virtueller Artikel',
	'texte_article_virtuel_reference' => '<b>Virtueller Artikel:</b> Dieser Artikel ist Teil Ihrer Website, leitet Besucher aber zu einer anderen URL um. Sie können die Umleitung abschalten, indem Sie den URL oben löschen.',
	'texte_aucun_resultat_auteur' => 'Kein Ergebnis für “@cherche_auteur@”',
	'texte_auteur_messagerie' => 'Die Website kann Ihnen eine Liste aktuell eingelogter Redakteure anzeigen, so dass Sie sofort miteinander in Kontakt treten können (Wenn das Nachrichtensystem abgeschaltet ist, gibt es auch keine Liste angemeldeter Redakteure). Sie haben die Möglichkeit, nicht in diese Liste aufgenommen zu werden (damit sind Sie für andere Benutzer "unsichtbar").',
	'texte_auteurs' => 'AUTOREN',
	'texte_choix_base_1' => 'Wählen Sie die Datenbank:',
	'texte_choix_base_2' => 'Der SQL-Server enthält mehrere Datenbanken.',
	'texte_choix_base_3' => '<b>Wählen</b> Sie die von Ihrem Webhoster für Sie angelegte aus:',
	'texte_choix_table_prefix' => 'Prefix der Tabellen:',
	'texte_compatibilite_html' => 'Sie können SPIP so einstellen, daß die öffentlichen Seiten in <i>HTML4</i> erstellt werden, oder in <i>HTML5</i> mit seinen erweiterten Leistungsmerkmalen.',
	'texte_compatibilite_html_attention' => 'Die Aktivierung von <i>HTML5</i> ist völlig ungefährlich, nur müssen ihre Seiten dann mit der folgenden Zeile beginnen, um der HTML-Norm zu entsprechen: <code>&lt;!DOCTYPE html&gt;</code>.',
	'texte_compte_element' => '@count@ Element',
	'texte_compte_elements' => '@count@ Elemente',
	'texte_conflit_edition_correction' => 'Bitte überprüfen sie hier die Unterschiede zwischen zwei Versionen des Textes. Sie können Ihre Änderungen kopieren und neu eingeben.',
	'texte_connexion_mysql' => 'Sie erhalten die erforderlichen SQL-Zugangsdaten von Ihrem Provider: Name des Datenbankservers und persönliche Zugangsdaten.',
	'texte_contenu_article' => '(Zusammenfassung des Artikels in wenigen Worten.)',
	'texte_contenu_articles' => 'Ja nach Vorlage, die Sie für Ihre Website verwenden, können Sie Elemente von Artikeln aktivieren oder abschalten. Bitte bestimmen Sie mit dieser Liste, welche Elemente verfügbar sein sollen.',
	'texte_crash_base' => 'Wenn Ihre Datenbank abgestürzt ist, können Sie eine automatische Reparatur versuchen.',
	'texte_creer_rubrique' => 'Bevor Sie Artikel schreiben können,<br /> müssen Sie eine Rubrik anlegen.',
	'texte_date_creation_article' => 'ARTIKEL ANGELEGT AM:',
	'texte_date_creation_objet' => 'Erstellungsdatum:', # on ajoute le &quot;:&quot;
	'texte_date_publication_anterieure' => 'DATUM EINER FRÜHEREN BEARBEITUNG',
	'texte_date_publication_anterieure_nonaffichee' => 'Kein Datum einer früheren Bearbeitung anzeigen.',
	'texte_date_publication_article' => 'ONLINE VERÖFFENTLICHT AM:',
	'texte_date_publication_objet' => 'Veröffentlichungsdatum:',
	'texte_definir_comme_traduction_rubrique' => 'Diese Rubrik ist eine Übersetzung der Rubik mit der Nummer',
	'texte_descriptif_rapide' => 'Kurzbeschreibung',
	'texte_effacer_base' => 'SPIP-Datenbank löschen',
	'texte_effacer_statistiques' => 'Statistiken löschen',
	'texte_en_cours_validation' => 'Die folgenden Einträge sind zur Veröffentlichung vorgeschlagen.',
	'texte_enrichir_mise_a_jour' => 'Sie können Ihren Text ansprechend gestalten, indem Sie die typografischen Abkürzungen verwenden.',
	'texte_fichier_authent' => '<b>Soll SPIP die Dateien <tt>.htpasswd</tt> und <tt>.htpasswd-admin</tt> im Verzeichnis @dossier@ anlegen?</b><p>
 Mit diesen Dateien können Sie den Zugang zu anderen Bereichen Ihrer Website (z.B. externe Logfile-Auswertungen) auf Redakteure und Administratoren beschränken.</p><p>Wenn Sie diese Möglickeit nicht nutzen, könnn Sie hier die Grundeinstellung (Dateien werden nicht angelegt) beibehalten.</p>',
	'texte_informations_personnelles_1' => 'Das System wird nun persönliche Zugangsdaten für Sie anlegen.',
	'texte_informations_personnelles_2' => '(Hinweis: Wenn Sie die Site erneut installieren, und Ihre Zugangsdaten funktionieren, können Sie',
	'texte_introductif_article' => '(Einleitender Text des Artikels.)',
	'texte_jeu_caractere' => 'Es empfiehlt sich, das Universalalphabet (<tt>utf-8</tt>) für ihre Website zu verwenden. Es ermöglicht die Darstellung der Zeichen aller Sprachen und wird nunmehr von allen modernen Webbrowsern unterstützt.',
	'texte_jeu_caractere_3' => 'Ihre Website verwendet zur Zeit den Zeichensatz:',
	'texte_jeu_caractere_4' => 'Wenn das nicht mit den Erfordernissen ihrer Daten übereinstimmt (z.B. nach der Wiederherstellung einer Datensicherung), oder wenn sie die Website neu einrichten und einen anderen Zeichernsatz verwenden möchten, stellen sie ihn bitte hier ein:',
	'texte_login_ldap_1' => '(Keine Angabe bzw. vollständiger Pfad, z.B. „<tt>uid=meier, ou=mitglieder, dc=MeineDomäne, dc=com</tt>“.)',
	'texte_login_precaution' => 'Achtung! Sie sind zur Zeit mit diesem Namen angemeldet. Bitte verwenden Sie diese Seite mit der erforderlichen Vorsicht.',
	'texte_messagerie_agenda' => 'Mit dem Nachrichtensystem können Redakteure im Redaktionsbereich direkt miteinander kommunizieren. Es ist mit einem Kalender verbunden.',
	'texte_mise_a_niveau_base_1' => 'Sie haben den Programmcode von SPIP aktualisiert. Jetzt muss die Datenbank aktualisiert werden.',
	'texte_modifier_article' => 'Artikel bearbeiten:',
	'texte_multilinguisme' => 'Wenn Sie Artikel in mehreren Sprachen mit entsprecher komplexer Navigation verwalten möchten, können Sie den Rubriken und/oder den Artikeln ein Menü zur Sprachauswahl hinzufügen. Diese Funktion ist abhängig von der Struktur Ihrer Website.',
	'texte_multilinguisme_trad' => 'Sie können ein System zur automatischen Verlinkung der verschiedenen Sprachversionen von Objekten aktivieren.',
	'texte_non_compresse' => '<i>unkomprimiert</i> (ihr Server unterstützt diese Funktion nicht)',
	'texte_nouvelle_version_spip_1' => 'Sie haben eine neue Version von SPIP installiert.',
	'texte_nouvelle_version_spip_2' => 'Diese neue Version erfordert eine weiter gehende Aktualisierung Ihres Systems als gewöhnlich. Wenn Sie Webmaster dieser Site sind, löschen Sie bitte die Datei @connect@ und setzen Sie die Installation fort, indem Sie die Verbindungsdaten zur Datenbank neu eingeben.<p>(Tipp: Sollten Sie Ihre Verbindungsdaten vergessen haben, schauen Sie in der Datei @connect@ nach, bevor Sie sie löschen ...)</p>',
	'texte_operation_echec' => 'Gehen Sie zur vorigen Seite zurück und wählen Sie eine andere Datenbank aus bzw. legen Sie eine neue an. Überprüfen Sie die Angaben Ihres Providers.',
	'texte_plus_trois_car' => 'mehr als 3 Zeichen',
	'texte_plusieurs_articles' => 'Mehrere Autoren für „@cherche_auteur@“ gefunden:',
	'texte_port_annuaire' => '(Der Standardwert kann meistens beibehalten werden.)',
	'texte_presente_plugin' => 'Diese Seite zeigt eine Liste der auf dieser Website verfügbaren Plugins. Sie können sie aktivieren, indem sie die entsprechenden Einträge mit einem Häkchen merkieren.',
	'texte_proposer_publication' => 'Wenn Ihr Artikel fertig ist,<br /> können Sie ihn zur Veröffentlichung vorschlagen.',
	'texte_proxy' => 'In manchen Fällen (Intranet, Rechner hinter einer Firewall...),
kann ein <i>HTTP-Proxy</i> erforderlich sein, um die syndizierten Websites zu erreichen.
 In diesem Fall geben Sie seine Adresse im Format
<tt><html>http://proxy:8080</html></tt>. an.
Meistens kann dieses Feld aber leer bleiben.',
	'texte_publication_articles_post_dates' => 'Wie soll SPIP Artikel behandeln, deren Erscheinungsdatum in die Zukunft gelegt wurde?',
	'texte_rappel_selection_champs' => '[Vergessen Sie nicht, dieses Feld korrekt auszufüllen.]',
	'texte_recalcul_page' => 'Wenn Sie nur eine einzelne Seite aktualisieren wollen, verwenden Sie besser den Schalter „Seite aus Cache löschen“.',
	'texte_recuperer_base' => 'Datenbank reparieren',
	'texte_reference_mais_redirige' => 'Artikel Ihrer Website, der eine Umleitung zu einem anderen URL enthält.',
	'texte_requetes_echouent' => '<b>Wenn manche SQL-Befehle ohne ersichtlichen Grund systematisch fehlschlagen, kann es an einer beschädigten Datenbank liegen.</b><p>
SQL kann Tabellen reparieren, die beschädigt worden sind. Starten Sie hier einen Reparaturversuch. Sollte das fehlschlagen, notieren Sie bitte die Fehlermeldung, die u.U. einen Hinweis auf die Ursache des Problems gibt ...<p>
Wenn das Problem weiter besteht, nehmen Sie bitte Kontakt mit Ihrem Provider auf.<p>',
	'texte_selection_langue_principale' => 'Hier können Sie die «Hauptsprache» der Website auswählen. Das zwingt Sie - zum Glück - nicht, Ihre Artikel in dieser Sprache zu schreiben, sondern ermöglicht:
        <ul><li> das Format der Datumsanzeige einzustellen;</li>
        <li> die Art der typografischen Korrekturen von SPIP zu bestimmen;</li>
        <li> über die Sprachversion der eingebauten Formulare zu entscheiden;</li>
        <li> die Standardsprache des Redaktionssystems zu verändern.</li></ul>',
	'texte_sous_titre' => 'Untertitel',
	'texte_statistiques_visites' => '(dunkle Balken : Sonntag / dunkle Kurve : Entwicklung der Durchschnittswerte)',
	'texte_statut_attente_validation' => 'vorgeschlagen',
	'texte_statut_publies' => 'veröffentlicht',
	'texte_statut_refuses' => 'abgelehnt',
	'texte_suppression_fichiers' => 'Benutzen Sie diesen Befehl, um alle Dateien aus dem Zwischenspeicher von SPIP zu löschen. Damit können Sie eine erneute Berechnung aller Seiten erzwingen, wenn Sie z.B. wesentliche Änderungen am Inhalt und Layout Ihrer Site gemacht haben. ',
	'texte_sur_titre' => 'Einleitender Titel',
	'texte_table_ok' => ': Tabelle OK.',
	'texte_tentative_recuperation' => 'Reparaturversuch',
	'texte_tenter_reparation' => 'Reparatur der Datenbank versuchen',
	'texte_test_proxy' => 'Um den Proxy zu testen, geben Sie hier die Adresse einer gewünschten Website ein.',
	'texte_titre_02' => 'Titel:',
	'texte_titre_obligatoire' => '<b>Titel</b> [obligatorisch]',
	'texte_travail_article' => '@nom_auteur_modif@ hat diesen Artikel vor @date_diff@ Minuten bearbeitet',
	'texte_travail_collaboratif' => 'Wenn es öfter vorkommt, dass mehrere Redakteure gemeinsam an Artikeln arbeiten, kann SPIP die vor kurzem „geöffneten“ Artikel anzeigen, um gleichzeitige Änderungen vorzubeugen. Diese Funktion ist normalerweise abgeschaltet, um störende Meldungen zu reduzieren.',
	'texte_vide' => 'leer',
	'texte_vider_cache' => 'Cache leeren',
	'titre_admin_tech' => 'Wartung',
	'titre_admin_vider' => 'Wartung',
	'titre_ajouter_un_auteur' => 'Autor hinzufügen',
	'titre_ajouter_un_mot' => 'Schlagwort hinzufügen',
	'titre_cadre_afficher_article' => 'Artikel anzeigen',
	'titre_cadre_afficher_traductions' => 'Stand der Übersetzungen für diese Sprachen anzeigen',
	'titre_cadre_ajouter_auteur' => 'AUTOR HINZUFÜGEN: ',
	'titre_cadre_interieur_rubrique' => 'In der Rubrik',
	'titre_cadre_numero_auteur' => 'AUTOR NUMMER',
	'titre_cadre_numero_objet' => '@objet@ Nummer:',
	'titre_cadre_signature_obligatoire' => '<b>Unterschrift</b> [obligatorisch]<br />',
	'titre_config_contenu_notifications' => 'Benachrichtigungen',
	'titre_config_contenu_prive' => 'Im Redaktionsbereich',
	'titre_config_contenu_public' => 'Auf der öffentlichen Website',
	'titre_config_fonctions' => 'Website konfigurieren',
	'titre_config_langage' => 'Sprache einstellen',
	'titre_configuration' => 'Website konfigurieren',
	'titre_configurer_preferences' => 'Ihre Einstellungen',
	'titre_conflit_edition' => 'Bearbeitungskonflikt',
	'titre_connexion_ldap' => 'Optionen: <b>LDAP-Verbindung</b>',
	'titre_groupe_mots' => 'KATEGORIE:',
	'titre_identite_site' => 'Name der Website', # &quot;Identité du site&quot; war &quot;Identität der Website&quot;, jetzt &quot;Name der Website&quot;, auch möglich &quot;Websitebezeichnung&quot; o.ä.
	'titre_langue_article' => 'Sprache des Artikels',
	'titre_langue_rubrique' => 'Sprache der Rubrik',
	'titre_langue_trad_article' => 'SPRACHE UND ÜBERSETZUNGEN DES ARTIKELS',
	'titre_les_articles' => 'ARTIKEL',
	'titre_messagerie_agenda' => 'Nachrichten und Kalender',
	'titre_naviguer_dans_le_site' => 'Sitenavigation ...',
	'titre_nouvelle_rubrique' => 'Neue Rubrik',
	'titre_numero_rubrique' => 'RUBRIK NUMMER:',
	'titre_page_articles_edit' => 'Bearbeiten: @titre@',
	'titre_page_articles_page' => 'Artikel',
	'titre_page_articles_tous' => 'Ganze Website',
	'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Website konfigurieren',
	'titre_page_delete_all' => 'vollständig unwiderruflich löschen',
	'titre_page_recherche' => 'Ergebnisse der Suche nach @recherche@',
	'titre_page_statistiques_referers' => 'Statistik (Referer)',
	'titre_page_upgrade' => 'Aktualisierung von SPIP',
	'titre_publication_articles_post_dates' => 'Veröffentlichung von vordatierten Artikeln',
	'titre_reparation' => 'Reparatur',
	'titre_suivi_petition' => 'Petitionen verwalten',
	'tls_ldap' => 'Transport Layer Security:',
	'trad_article_traduction' => 'Alle Fassungen dieses Artikels:',
	'trad_delier' => 'Nicht mehr mit diesen Übersetzungen verbinden',
	'trad_lier' => 'Dieser Artikel ist eine Übersetzung des Artikels Nummer ',
	'trad_new' => 'Neue Übersetzung beginnen',

	// U
	'utf8_convert_erreur_orig' => 'Fehler: Der Zeichensatz @charset@ wird nicht unterstützt.',

	// V
	'version' => 'Version:'
);

?>
